from typing import Any
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import tfplugin6_5_pb2 as tfplugin6__5__pb2


class ProviderStub(object):
    """////// Information about what a provider supports/expects
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetMetadata = channel.unary_unary(
                '/tfplugin6.Provider/GetMetadata',
                request_serializer=tfplugin6__5__pb2.GetMetadata.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.GetMetadata.Response.FromString,
                )
        self.GetProviderSchema = channel.unary_unary(
                '/tfplugin6.Provider/GetProviderSchema',
                request_serializer=tfplugin6__5__pb2.GetProviderSchema.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.GetProviderSchema.Response.FromString,
                )
        self.ValidateProviderConfig = channel.unary_unary(
                '/tfplugin6.Provider/ValidateProviderConfig',
                request_serializer=tfplugin6__5__pb2.ValidateProviderConfig.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.ValidateProviderConfig.Response.FromString,
                )
        self.ValidateResourceConfig = channel.unary_unary(
                '/tfplugin6.Provider/ValidateResourceConfig',
                request_serializer=tfplugin6__5__pb2.ValidateResourceConfig.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.ValidateResourceConfig.Response.FromString,
                )
        self.ValidateDataResourceConfig = channel.unary_unary(
                '/tfplugin6.Provider/ValidateDataResourceConfig',
                request_serializer=tfplugin6__5__pb2.ValidateDataResourceConfig.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.ValidateDataResourceConfig.Response.FromString,
                )
        self.UpgradeResourceState = channel.unary_unary(
                '/tfplugin6.Provider/UpgradeResourceState',
                request_serializer=tfplugin6__5__pb2.UpgradeResourceState.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.UpgradeResourceState.Response.FromString,
                )
        self.ConfigureProvider = channel.unary_unary(
                '/tfplugin6.Provider/ConfigureProvider',
                request_serializer=tfplugin6__5__pb2.ConfigureProvider.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.ConfigureProvider.Response.FromString,
                )
        self.ReadResource = channel.unary_unary(
                '/tfplugin6.Provider/ReadResource',
                request_serializer=tfplugin6__5__pb2.ReadResource.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.ReadResource.Response.FromString,
                )
        self.PlanResourceChange = channel.unary_unary(
                '/tfplugin6.Provider/PlanResourceChange',
                request_serializer=tfplugin6__5__pb2.PlanResourceChange.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.PlanResourceChange.Response.FromString,
                )
        self.ApplyResourceChange = channel.unary_unary(
                '/tfplugin6.Provider/ApplyResourceChange',
                request_serializer=tfplugin6__5__pb2.ApplyResourceChange.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.ApplyResourceChange.Response.FromString,
                )
        self.ImportResourceState = channel.unary_unary(
                '/tfplugin6.Provider/ImportResourceState',
                request_serializer=tfplugin6__5__pb2.ImportResourceState.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.ImportResourceState.Response.FromString,
                )
        self.ReadDataSource = channel.unary_unary(
                '/tfplugin6.Provider/ReadDataSource',
                request_serializer=tfplugin6__5__pb2.ReadDataSource.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.ReadDataSource.Response.FromString,
                )
        self.GetFunctions = channel.unary_unary(
                '/tfplugin6.Provider/GetFunctions',
                request_serializer=tfplugin6__5__pb2.GetFunctions.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.GetFunctions.Response.FromString,
                )
        self.CallFunction = channel.unary_unary(
                '/tfplugin6.Provider/CallFunction',
                request_serializer=tfplugin6__5__pb2.CallFunction.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.CallFunction.Response.FromString,
                )
        self.StopProvider = channel.unary_unary(
                '/tfplugin6.Provider/StopProvider',
                request_serializer=tfplugin6__5__pb2.StopProvider.Request.SerializeToString,
                response_deserializer=tfplugin6__5__pb2.StopProvider.Response.FromString,
                )


class ProviderServicer(object):
    """////// Information about what a provider supports/expects
    """

    def GetMetadata(self, request, context):
        """GetMetadata returns upfront information about server capabilities and
        supported resource types without requiring the server to instantiate all
        schema information, which may be memory intensive. This RPC is optional,
        where clients may receive an unimplemented RPC error. Clients should
        ignore the error and call the GetProviderSchema RPC as a fallback.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProviderSchema(self, request, context):
        """GetSchema returns schema information for the provider, data resources,
        and managed resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateProviderConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateResourceConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateDataResourceConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpgradeResourceState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureProvider(self, request, context):
        """////// One-time initialization, called before other functions below
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadResource(self, request, context):
        """////// Managed Resource Lifecycle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlanResourceChange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyResourceChange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ImportResourceState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadDataSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFunctions(self, request, context):
        """GetFunctions returns the definitions of all functions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CallFunction(self, request, context):
        """////// Provider-contributed Functions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopProvider(self, request, context):
        """////// Graceful Shutdown
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProviderServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetadata,
                    request_deserializer=tfplugin6__5__pb2.GetMetadata.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.GetMetadata.Response.SerializeToString,
            ),
            'GetProviderSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProviderSchema,
                    request_deserializer=tfplugin6__5__pb2.GetProviderSchema.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.GetProviderSchema.Response.SerializeToString,
            ),
            'ValidateProviderConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateProviderConfig,
                    request_deserializer=tfplugin6__5__pb2.ValidateProviderConfig.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.ValidateProviderConfig.Response.SerializeToString,
            ),
            'ValidateResourceConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateResourceConfig,
                    request_deserializer=tfplugin6__5__pb2.ValidateResourceConfig.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.ValidateResourceConfig.Response.SerializeToString,
            ),
            'ValidateDataResourceConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateDataResourceConfig,
                    request_deserializer=tfplugin6__5__pb2.ValidateDataResourceConfig.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.ValidateDataResourceConfig.Response.SerializeToString,
            ),
            'UpgradeResourceState': grpc.unary_unary_rpc_method_handler(
                    servicer.UpgradeResourceState,
                    request_deserializer=tfplugin6__5__pb2.UpgradeResourceState.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.UpgradeResourceState.Response.SerializeToString,
            ),
            'ConfigureProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureProvider,
                    request_deserializer=tfplugin6__5__pb2.ConfigureProvider.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.ConfigureProvider.Response.SerializeToString,
            ),
            'ReadResource': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadResource,
                    request_deserializer=tfplugin6__5__pb2.ReadResource.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.ReadResource.Response.SerializeToString,
            ),
            'PlanResourceChange': grpc.unary_unary_rpc_method_handler(
                    servicer.PlanResourceChange,
                    request_deserializer=tfplugin6__5__pb2.PlanResourceChange.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.PlanResourceChange.Response.SerializeToString,
            ),
            'ApplyResourceChange': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyResourceChange,
                    request_deserializer=tfplugin6__5__pb2.ApplyResourceChange.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.ApplyResourceChange.Response.SerializeToString,
            ),
            'ImportResourceState': grpc.unary_unary_rpc_method_handler(
                    servicer.ImportResourceState,
                    request_deserializer=tfplugin6__5__pb2.ImportResourceState.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.ImportResourceState.Response.SerializeToString,
            ),
            'ReadDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadDataSource,
                    request_deserializer=tfplugin6__5__pb2.ReadDataSource.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.ReadDataSource.Response.SerializeToString,
            ),
            'GetFunctions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFunctions,
                    request_deserializer=tfplugin6__5__pb2.GetFunctions.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.GetFunctions.Response.SerializeToString,
            ),
            'CallFunction': grpc.unary_unary_rpc_method_handler(
                    servicer.CallFunction,
                    request_deserializer=tfplugin6__5__pb2.CallFunction.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.CallFunction.Response.SerializeToString,
            ),
            'StopProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.StopProvider,
                    request_deserializer=tfplugin6__5__pb2.StopProvider.Request.FromString,
                    response_serializer=tfplugin6__5__pb2.StopProvider.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tfplugin6.Provider', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Provider(object):
    """////// Information about what a provider supports/expects
    """

    @staticmethod
    def GetMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/GetMetadata',
            tfplugin6__5__pb2.GetMetadata.Request.SerializeToString,
            tfplugin6__5__pb2.GetMetadata.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProviderSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/GetProviderSchema',
            tfplugin6__5__pb2.GetProviderSchema.Request.SerializeToString,
            tfplugin6__5__pb2.GetProviderSchema.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateProviderConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ValidateProviderConfig',
            tfplugin6__5__pb2.ValidateProviderConfig.Request.SerializeToString,
            tfplugin6__5__pb2.ValidateProviderConfig.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateResourceConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ValidateResourceConfig',
            tfplugin6__5__pb2.ValidateResourceConfig.Request.SerializeToString,
            tfplugin6__5__pb2.ValidateResourceConfig.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateDataResourceConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ValidateDataResourceConfig',
            tfplugin6__5__pb2.ValidateDataResourceConfig.Request.SerializeToString,
            tfplugin6__5__pb2.ValidateDataResourceConfig.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpgradeResourceState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/UpgradeResourceState',
            tfplugin6__5__pb2.UpgradeResourceState.Request.SerializeToString,
            tfplugin6__5__pb2.UpgradeResourceState.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ConfigureProvider',
            tfplugin6__5__pb2.ConfigureProvider.Request.SerializeToString,
            tfplugin6__5__pb2.ConfigureProvider.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ReadResource',
            tfplugin6__5__pb2.ReadResource.Request.SerializeToString,
            tfplugin6__5__pb2.ReadResource.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlanResourceChange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/PlanResourceChange',
            tfplugin6__5__pb2.PlanResourceChange.Request.SerializeToString,
            tfplugin6__5__pb2.PlanResourceChange.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyResourceChange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ApplyResourceChange',
            tfplugin6__5__pb2.ApplyResourceChange.Request.SerializeToString,
            tfplugin6__5__pb2.ApplyResourceChange.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ImportResourceState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ImportResourceState',
            tfplugin6__5__pb2.ImportResourceState.Request.SerializeToString,
            tfplugin6__5__pb2.ImportResourceState.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ReadDataSource',
            tfplugin6__5__pb2.ReadDataSource.Request.SerializeToString,
            tfplugin6__5__pb2.ReadDataSource.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFunctions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/GetFunctions',
            tfplugin6__5__pb2.GetFunctions.Request.SerializeToString,
            tfplugin6__5__pb2.GetFunctions.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CallFunction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/CallFunction',
            tfplugin6__5__pb2.CallFunction.Request.SerializeToString,
            tfplugin6__5__pb2.CallFunction.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/StopProvider',
            tfplugin6__5__pb2.StopProvider.Request.SerializeToString,
            tfplugin6__5__pb2.StopProvider.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import Any
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tfplugin5_2.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11tfplugin5_2.proto\x12\ttfplugin5\"-\n\x0c\x44ynamicValue\x12\x0f\n\x07msgpack\x18\x01 \x01(\x0c\x12\x0c\n\x04json\x18\x02 \x01(\x0c\"\xbd\x01\n\nDiagnostic\x12\x30\n\x08severity\x18\x01 \x01(\x0e\x32\x1e.tfplugin5.Diagnostic.Severity\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x0e\n\x06\x64\x65tail\x18\x03 \x01(\t\x12+\n\tattribute\x18\x04 \x01(\x0b\x32\x18.tfplugin5.AttributePath\"/\n\x08Severity\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x0b\n\x07WARNING\x10\x02\"\xa4\x01\n\rAttributePath\x12,\n\x05steps\x18\x01 \x03(\x0b\x32\x1d.tfplugin5.AttributePath.Step\x1a\x65\n\x04Step\x12\x18\n\x0e\x61ttribute_name\x18\x01 \x01(\tH\x00\x12\x1c\n\x12\x65lement_key_string\x18\x02 \x01(\tH\x00\x12\x19\n\x0f\x65lement_key_int\x18\x03 \x01(\x03H\x00\x42\n\n\x08selector\",\n\x04Stop\x1a\t\n\x07Request\x1a\x19\n\x08Response\x12\r\n\x05\x45rror\x18\x01 \x01(\t\"{\n\x08RawState\x12\x0c\n\x04json\x18\x01 \x01(\x0c\x12\x31\n\x07\x66latmap\x18\x02 \x03(\x0b\x32 .tfplugin5.RawState.FlatmapEntry\x1a.\n\x0c\x46latmapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe4\x05\n\x06Schema\x12\x0f\n\x07version\x18\x01 \x01(\x03\x12&\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x17.tfplugin5.Schema.Block\x1a\xd7\x01\n\x05\x42lock\x12\x0f\n\x07version\x18\x01 \x01(\x03\x12/\n\nattributes\x18\x02 \x03(\x0b\x32\x1b.tfplugin5.Schema.Attribute\x12\x32\n\x0b\x62lock_types\x18\x03 \x03(\x0b\x32\x1d.tfplugin5.Schema.NestedBlock\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12/\n\x10\x64\x65scription_kind\x18\x05 \x01(\x0e\x32\x15.tfplugin5.StringKind\x12\x12\n\ndeprecated\x18\x06 \x01(\x08\x1a\xca\x01\n\tAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x0c\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08required\x18\x04 \x01(\x08\x12\x10\n\x08optional\x18\x05 \x01(\x08\x12\x10\n\x08\x63omputed\x18\x06 \x01(\x08\x12\x11\n\tsensitive\x18\x07 \x01(\x08\x12/\n\x10\x64\x65scription_kind\x18\x08 \x01(\x0e\x32\x15.tfplugin5.StringKind\x12\x12\n\ndeprecated\x18\t \x01(\x08\x1a\xf9\x01\n\x0bNestedBlock\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12&\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x17.tfplugin5.Schema.Block\x12:\n\x07nesting\x18\x03 \x01(\x0e\x32).tfplugin5.Schema.NestedBlock.NestingMode\x12\x11\n\tmin_items\x18\x04 \x01(\x03\x12\x11\n\tmax_items\x18\x05 \x01(\x03\"M\n\x0bNestingMode\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06SINGLE\x10\x01\x12\x08\n\x04LIST\x10\x02\x12\x07\n\x03SET\x10\x03\x12\x07\n\x03MAP\x10\x04\x12\t\n\x05GROUP\x10\x05\"\xef\x03\n\x11GetProviderSchema\x1a\t\n\x07Request\x1a\xce\x03\n\x08Response\x12#\n\x08provider\x18\x01 \x01(\x0b\x32\x11.tfplugin5.Schema\x12T\n\x10resource_schemas\x18\x02 \x03(\x0b\x32:.tfplugin5.GetProviderSchema.Response.ResourceSchemasEntry\x12Y\n\x13\x64\x61ta_source_schemas\x18\x03 \x03(\x0b\x32<.tfplugin5.GetProviderSchema.Response.DataSourceSchemasEntry\x12*\n\x0b\x64iagnostics\x18\x04 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\x12(\n\rprovider_meta\x18\x05 \x01(\x0b\x32\x11.tfplugin5.Schema\x1aI\n\x14ResourceSchemasEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.tfplugin5.Schema:\x02\x38\x01\x1aK\n\x16\x44\x61taSourceSchemasEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.tfplugin5.Schema:\x02\x38\x01\"\xb5\x01\n\x15PrepareProviderConfig\x1a\x32\n\x07Request\x12\'\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1ah\n\x08Response\x12\x30\n\x0fprepared_config\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\xd6\x01\n\x14UpgradeResourceState\x1aU\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x03\x12&\n\traw_state\x18\x03 \x01(\x0b\x32\x13.tfplugin5.RawState\x1ag\n\x08Response\x12/\n\x0eupgraded_state\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\x9b\x01\n\x1aValidateResourceTypeConfig\x1a\x45\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a\x36\n\x08Response\x12*\n\x0b\x64iagnostics\x18\x01 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\x99\x01\n\x18ValidateDataSourceConfig\x1a\x45\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a\x36\n\x08Response\x12*\n\x0b\x64iagnostics\x18\x01 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\x92\x01\n\tConfigure\x1aM\n\x07Request\x12\x19\n\x11terraform_version\x18\x01 \x01(\t\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a\x36\n\x08Response\x12*\n\x0b\x64iagnostics\x18\x01 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\x93\x02\n\x0cReadResource\x1a\x8d\x01\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12.\n\rcurrent_state\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x0f\n\x07private\x18\x03 \x01(\x0c\x12.\n\rprovider_meta\x18\x04 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1as\n\x08Response\x12*\n\tnew_state\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\x12\x0f\n\x07private\x18\x03 \x01(\x0c\"\xd8\x03\n\x12PlanResourceChange\x1a\xef\x01\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12,\n\x0bprior_state\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x33\n\x12proposed_new_state\x18\x03 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\'\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x15\n\rprior_private\x18\x05 \x01(\x0c\x12.\n\rprovider_meta\x18\x06 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a\xcf\x01\n\x08Response\x12.\n\rplanned_state\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x32\n\x10requires_replace\x18\x02 \x03(\x0b\x32\x18.tfplugin5.AttributePath\x12\x17\n\x0fplanned_private\x18\x03 \x01(\x0c\x12*\n\x0b\x64iagnostics\x18\x04 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\x12\x1a\n\x12legacy_type_system\x18\x05 \x01(\x08\"\x96\x03\n\x13\x41pplyResourceChange\x1a\xec\x01\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12,\n\x0bprior_state\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12.\n\rplanned_state\x18\x03 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\'\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x17\n\x0fplanned_private\x18\x05 \x01(\x0c\x12.\n\rprovider_meta\x18\x06 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a\x8f\x01\n\x08Response\x12*\n\tnew_state\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x0f\n\x07private\x18\x02 \x01(\x0c\x12*\n\x0b\x64iagnostics\x18\x03 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\x12\x1a\n\x12legacy_type_system\x18\x04 \x01(\x08\"\xa5\x02\n\x13ImportResourceState\x1a(\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x1a^\n\x10ImportedResource\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12&\n\x05state\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x0f\n\x07private\x18\x03 \x01(\x0c\x1a\x83\x01\n\x08Response\x12K\n\x12imported_resources\x18\x01 \x03(\x0b\x32/.tfplugin5.ImportResourceState.ImportedResource\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\xe7\x01\n\x0eReadDataSource\x1au\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12.\n\rprovider_meta\x18\x03 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a^\n\x08Response\x12&\n\x05state\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\x81\x01\n\x14GetProvisionerSchema\x1a\t\n\x07Request\x1a^\n\x08Response\x12&\n\x0bprovisioner\x18\x01 \x01(\x0b\x32\x11.tfplugin5.Schema\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\x87\x01\n\x19ValidateProvisionerConfig\x1a\x32\n\x07Request\x12\'\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a\x36\n\x08Response\x12*\n\x0b\x64iagnostics\x18\x01 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\xbc\x01\n\x11ProvisionResource\x1a_\n\x07Request\x12\'\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12+\n\nconnection\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a\x46\n\x08Response\x12\x0e\n\x06output\x18\x01 \x01(\t\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic*%\n\nStringKind\x12\t\n\x05PLAIN\x10\x00\x12\x0c\n\x08MARKDOWN\x10\x01\x32\x97\t\n\x08Provider\x12X\n\tGetSchema\x12$.tfplugin5.GetProviderSchema.Request\x1a%.tfplugin5.GetProviderSchema.Response\x12l\n\x15PrepareProviderConfig\x12(.tfplugin5.PrepareProviderConfig.Request\x1a).tfplugin5.PrepareProviderConfig.Response\x12{\n\x1aValidateResourceTypeConfig\x12-.tfplugin5.ValidateResourceTypeConfig.Request\x1a..tfplugin5.ValidateResourceTypeConfig.Response\x12u\n\x18ValidateDataSourceConfig\x12+.tfplugin5.ValidateDataSourceConfig.Request\x1a,.tfplugin5.ValidateDataSourceConfig.Response\x12i\n\x14UpgradeResourceState\x12\'.tfplugin5.UpgradeResourceState.Request\x1a(.tfplugin5.UpgradeResourceState.Response\x12H\n\tConfigure\x12\x1c.tfplugin5.Configure.Request\x1a\x1d.tfplugin5.Configure.Response\x12Q\n\x0cReadResource\x12\x1f.tfplugin5.ReadResource.Request\x1a .tfplugin5.ReadResource.Response\x12\x63\n\x12PlanResourceChange\x12%.tfplugin5.PlanResourceChange.Request\x1a&.tfplugin5.PlanResourceChange.Response\x12\x66\n\x13\x41pplyResourceChange\x12&.tfplugin5.ApplyResourceChange.Request\x1a\'.tfplugin5.ApplyResourceChange.Response\x12\x66\n\x13ImportResourceState\x12&.tfplugin5.ImportResourceState.Request\x1a\'.tfplugin5.ImportResourceState.Response\x12W\n\x0eReadDataSource\x12!.tfplugin5.ReadDataSource.Request\x1a\".tfplugin5.ReadDataSource.Response\x12\x39\n\x04Stop\x12\x17.tfplugin5.Stop.Request\x1a\x18.tfplugin5.Stop.Response2\x86\x03\n\x0bProvisioner\x12^\n\tGetSchema\x12\'.tfplugin5.GetProvisionerSchema.Request\x1a(.tfplugin5.GetProvisionerSchema.Response\x12x\n\x19ValidateProvisionerConfig\x12,.tfplugin5.ValidateProvisionerConfig.Request\x1a-.tfplugin5.ValidateProvisionerConfig.Response\x12\x62\n\x11ProvisionResource\x12$.tfplugin5.ProvisionResource.Request\x1a%.tfplugin5.ProvisionResource.Response0\x01\x12\x39\n\x04Stop\x12\x17.tfplugin5.Stop.Request\x1a\x18.tfplugin5.Stop.ResponseB3Z1github.com/hashicorp/terraform/internal/tfplugin5b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tfplugin5_2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/hashicorp/terraform/internal/tfplugin5'
  _RAWSTATE_FLATMAPENTRY._options = None
  _RAWSTATE_FLATMAPENTRY._serialized_options = b'8\001'
  _GETPROVIDERSCHEMA_RESPONSE_RESOURCESCHEMASENTRY._options = None
  _GETPROVIDERSCHEMA_RESPONSE_RESOURCESCHEMASENTRY._serialized_options = b'8\001'
  _GETPROVIDERSCHEMA_RESPONSE_DATASOURCESCHEMASENTRY._options = None
  _GETPROVIDERSCHEMA_RESPONSE_DATASOURCESCHEMASENTRY._serialized_options = b'8\001'
  _globals['_STRINGKIND']._serialized_start=4867
  _globals['_STRINGKIND']._serialized_end=4904
  _globals['_DYNAMICVALUE']._serialized_start=32
  _globals['_DYNAMICVALUE']._serialized_end=77
  _globals['_DIAGNOSTIC']._serialized_start=80
  _globals['_DIAGNOSTIC']._serialized_end=269
  _globals['_DIAGNOSTIC_SEVERITY']._serialized_start=222
  _globals['_DIAGNOSTIC_SEVERITY']._serialized_end=269
  _globals['_ATTRIBUTEPATH']._serialized_start=272
  _globals['_ATTRIBUTEPATH']._serialized_end=436
  _globals['_ATTRIBUTEPATH_STEP']._serialized_start=335
  _globals['_ATTRIBUTEPATH_STEP']._serialized_end=436
  _globals['_STOP']._serialized_start=438
  _globals['_STOP']._serialized_end=482
  _globals['_STOP_REQUEST']._serialized_start=446
  _globals['_STOP_REQUEST']._serialized_end=455
  _globals['_STOP_RESPONSE']._serialized_start=457
  _globals['_STOP_RESPONSE']._serialized_end=482
  _globals['_RAWSTATE']._serialized_start=484
  _globals['_RAWSTATE']._serialized_end=607
  _globals['_RAWSTATE_FLATMAPENTRY']._serialized_start=561
  _globals['_RAWSTATE_FLATMAPENTRY']._serialized_end=607
  _globals['_SCHEMA']._serialized_start=610
  _globals['_SCHEMA']._serialized_end=1350
  _globals['_SCHEMA_BLOCK']._serialized_start=678
  _globals['_SCHEMA_BLOCK']._serialized_end=893
  _globals['_SCHEMA_ATTRIBUTE']._serialized_start=896
  _globals['_SCHEMA_ATTRIBUTE']._serialized_end=1098
  _globals['_SCHEMA_NESTEDBLOCK']._serialized_start=1101
  _globals['_SCHEMA_NESTEDBLOCK']._serialized_end=1350
  _globals['_SCHEMA_NESTEDBLOCK_NESTINGMODE']._serialized_start=1273
  _globals['_SCHEMA_NESTEDBLOCK_NESTINGMODE']._serialized_end=1350
  _globals['_GETPROVIDERSCHEMA']._serialized_start=1353
  _globals['_GETPROVIDERSCHEMA']._serialized_end=1848
  _globals['_GETPROVIDERSCHEMA_REQUEST']._serialized_start=446
  _globals['_GETPROVIDERSCHEMA_REQUEST']._serialized_end=455
  _globals['_GETPROVIDERSCHEMA_RESPONSE']._serialized_start=1386
  _globals['_GETPROVIDERSCHEMA_RESPONSE']._serialized_end=1848
  _globals['_GETPROVIDERSCHEMA_RESPONSE_RESOURCESCHEMASENTRY']._serialized_start=1698
  _globals['_GETPROVIDERSCHEMA_RESPONSE_RESOURCESCHEMASENTRY']._serialized_end=1771
  _globals['_GETPROVIDERSCHEMA_RESPONSE_DATASOURCESCHEMASENTRY']._serialized_start=1773
  _globals['_GETPROVIDERSCHEMA_RESPONSE_DATASOURCESCHEMASENTRY']._serialized_end=1848
  _globals['_PREPAREPROVIDERCONFIG']._serialized_start=1851
  _globals['_PREPAREPROVIDERCONFIG']._serialized_end=2032
  _globals['_PREPAREPROVIDERCONFIG_REQUEST']._serialized_start=1876
  _globals['_PREPAREPROVIDERCONFIG_REQUEST']._serialized_end=1926
  _globals['_PREPAREPROVIDERCONFIG_RESPONSE']._serialized_start=1928
  _globals['_PREPAREPROVIDERCONFIG_RESPONSE']._serialized_end=2032
  _globals['_UPGRADERESOURCESTATE']._serialized_start=2035
  _globals['_UPGRADERESOURCESTATE']._serialized_end=2249
  _globals['_UPGRADERESOURCESTATE_REQUEST']._serialized_start=2059
  _globals['_UPGRADERESOURCESTATE_REQUEST']._serialized_end=2144
  _globals['_UPGRADERESOURCESTATE_RESPONSE']._serialized_start=2146
  _globals['_UPGRADERESOURCESTATE_RESPONSE']._serialized_end=2249
  _globals['_VALIDATERESOURCETYPECONFIG']._serialized_start=2252
  _globals['_VALIDATERESOURCETYPECONFIG']._serialized_end=2407
  _globals['_VALIDATERESOURCETYPECONFIG_REQUEST']._serialized_start=2282
  _globals['_VALIDATERESOURCETYPECONFIG_REQUEST']._serialized_end=2351
  _globals['_VALIDATERESOURCETYPECONFIG_RESPONSE']._serialized_start=2353
  _globals['_VALIDATERESOURCETYPECONFIG_RESPONSE']._serialized_end=2407
  _globals['_VALIDATEDATASOURCECONFIG']._serialized_start=2410
  _globals['_VALIDATEDATASOURCECONFIG']._serialized_end=2563
  _globals['_VALIDATEDATASOURCECONFIG_REQUEST']._serialized_start=2282
  _globals['_VALIDATEDATASOURCECONFIG_REQUEST']._serialized_end=2351
  _globals['_VALIDATEDATASOURCECONFIG_RESPONSE']._serialized_start=2353
  _globals['_VALIDATEDATASOURCECONFIG_RESPONSE']._serialized_end=2407
  _globals['_CONFIGURE']._serialized_start=2566
  _globals['_CONFIGURE']._serialized_end=2712
  _globals['_CONFIGURE_REQUEST']._serialized_start=2579
  _globals['_CONFIGURE_REQUEST']._serialized_end=2656
  _globals['_CONFIGURE_RESPONSE']._serialized_start=2353
  _globals['_CONFIGURE_RESPONSE']._serialized_end=2407
  _globals['_READRESOURCE']._serialized_start=2715
  _globals['_READRESOURCE']._serialized_end=2990
  _globals['_READRESOURCE_REQUEST']._serialized_start=2732
  _globals['_READRESOURCE_REQUEST']._serialized_end=2873
  _globals['_READRESOURCE_RESPONSE']._serialized_start=2875
  _globals['_READRESOURCE_RESPONSE']._serialized_end=2990
  _globals['_PLANRESOURCECHANGE']._serialized_start=2993
  _globals['_PLANRESOURCECHANGE']._serialized_end=3465
  _globals['_PLANRESOURCECHANGE_REQUEST']._serialized_start=3016
  _globals['_PLANRESOURCECHANGE_REQUEST']._serialized_end=3255
  _globals['_PLANRESOURCECHANGE_RESPONSE']._serialized_start=3258
  _globals['_PLANRESOURCECHANGE_RESPONSE']._serialized_end=3465
  _globals['_APPLYRESOURCECHANGE']._serialized_start=3468
  _globals['_APPLYRESOURCECHANGE']._serialized_end=3874
  _globals['_APPLYRESOURCECHANGE_REQUEST']._serialized_start=3492
  _globals['_APPLYRESOURCECHANGE_REQUEST']._serialized_end=3728
  _globals['_APPLYRESOURCECHANGE_RESPONSE']._serialized_start=3731
  _globals['_APPLYRESOURCECHANGE_RESPONSE']._serialized_end=3874
  _globals['_IMPORTRESOURCESTATE']._serialized_start=3877
  _globals['_IMPORTRESOURCESTATE']._serialized_end=4170
  _globals['_IMPORTRESOURCESTATE_REQUEST']._serialized_start=3900
  _globals['_IMPORTRESOURCESTATE_REQUEST']._serialized_end=3940
  _globals['_IMPORTRESOURCESTATE_IMPORTEDRESOURCE']._serialized_start=3942
  _globals['_IMPORTRESOURCESTATE_IMPORTEDRESOURCE']._serialized_end=4036
  _globals['_IMPORTRESOURCESTATE_RESPONSE']._serialized_start=4039
  _globals['_IMPORTRESOURCESTATE_RESPONSE']._serialized_end=4170
  _globals['_READDATASOURCE']._serialized_start=4173
  _globals['_READDATASOURCE']._serialized_end=4404
  _globals['_READDATASOURCE_REQUEST']._serialized_start=4191
  _globals['_READDATASOURCE_REQUEST']._serialized_end=4308
  _globals['_READDATASOURCE_RESPONSE']._serialized_start=4310
  _globals['_READDATASOURCE_RESPONSE']._serialized_end=4404
  _globals['_GETPROVISIONERSCHEMA']._serialized_start=4407
  _globals['_GETPROVISIONERSCHEMA']._serialized_end=4536
  _globals['_GETPROVISIONERSCHEMA_REQUEST']._serialized_start=446
  _globals['_GETPROVISIONERSCHEMA_REQUEST']._serialized_end=455
  _globals['_GETPROVISIONERSCHEMA_RESPONSE']._serialized_start=4442
  _globals['_GETPROVISIONERSCHEMA_RESPONSE']._serialized_end=4536
  _globals['_VALIDATEPROVISIONERCONFIG']._serialized_start=4539
  _globals['_VALIDATEPROVISIONERCONFIG']._serialized_end=4674
  _globals['_VALIDATEPROVISIONERCONFIG_REQUEST']._serialized_start=1876
  _globals['_VALIDATEPROVISIONERCONFIG_REQUEST']._serialized_end=1926
  _globals['_VALIDATEPROVISIONERCONFIG_RESPONSE']._serialized_start=2353
  _globals['_VALIDATEPROVISIONERCONFIG_RESPONSE']._serialized_end=2407
  _globals['_PROVISIONRESOURCE']._serialized_start=4677
  _globals['_PROVISIONRESOURCE']._serialized_end=4865
  _globals['_PROVISIONRESOURCE_REQUEST']._serialized_start=4698
  _globals['_PROVISIONRESOURCE_REQUEST']._serialized_end=4793
  _globals['_PROVISIONRESOURCE_RESPONSE']._serialized_start=4795
  _globals['_PROVISIONRESOURCE_RESPONSE']._serialized_end=4865
  _globals['_PROVIDER']._serialized_start=4907
  _globals['_PROVIDER']._serialized_end=6082
  _globals['_PROVISIONER']._serialized_start=6085
  _globals['_PROVISIONER']._serialized_end=6475
# @@protoc_insertion_point(module_scope)



from typing import Any
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tfplugin5_0.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11tfplugin5_0.proto\x12\ttfplugin5\"-\n\x0c\x44ynamicValue\x12\x0f\n\x07msgpack\x18\x01 \x01(\x0c\x12\x0c\n\x04json\x18\x02 \x01(\x0c\"\xbd\x01\n\nDiagnostic\x12\x30\n\x08severity\x18\x01 \x01(\x0e\x32\x1e.tfplugin5.Diagnostic.Severity\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x0e\n\x06\x64\x65tail\x18\x03 \x01(\t\x12+\n\tattribute\x18\x04 \x01(\x0b\x32\x18.tfplugin5.AttributePath\"/\n\x08Severity\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x0b\n\x07WARNING\x10\x02\"\xa4\x01\n\rAttributePath\x12,\n\x05steps\x18\x01 \x03(\x0b\x32\x1d.tfplugin5.AttributePath.Step\x1a\x65\n\x04Step\x12\x18\n\x0e\x61ttribute_name\x18\x01 \x01(\tH\x00\x12\x1c\n\x12\x65lement_key_string\x18\x02 \x01(\tH\x00\x12\x19\n\x0f\x65lement_key_int\x18\x03 \x01(\x03H\x00\x42\n\n\x08selector\",\n\x04Stop\x1a\t\n\x07Request\x1a\x19\n\x08Response\x12\r\n\x05\x45rror\x18\x01 \x01(\t\"{\n\x08RawState\x12\x0c\n\x04json\x18\x01 \x01(\x0c\x12\x31\n\x07\x66latmap\x18\x02 \x03(\x0b\x32 .tfplugin5.RawState.FlatmapEntry\x1a.\n\x0c\x46latmapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc4\x04\n\x06Schema\x12\x0f\n\x07version\x18\x01 \x01(\x03\x12&\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x17.tfplugin5.Schema.Block\x1a}\n\x05\x42lock\x12\x0f\n\x07version\x18\x01 \x01(\x03\x12/\n\nattributes\x18\x02 \x03(\x0b\x32\x1b.tfplugin5.Schema.Attribute\x12\x32\n\x0b\x62lock_types\x18\x03 \x03(\x0b\x32\x1d.tfplugin5.Schema.NestedBlock\x1a\x85\x01\n\tAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x0c\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08required\x18\x04 \x01(\x08\x12\x10\n\x08optional\x18\x05 \x01(\x08\x12\x10\n\x08\x63omputed\x18\x06 \x01(\x08\x12\x11\n\tsensitive\x18\x07 \x01(\x08\x1a\xf9\x01\n\x0bNestedBlock\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12&\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x17.tfplugin5.Schema.Block\x12:\n\x07nesting\x18\x03 \x01(\x0e\x32).tfplugin5.Schema.NestedBlock.NestingMode\x12\x11\n\tmin_items\x18\x04 \x01(\x03\x12\x11\n\tmax_items\x18\x05 \x01(\x03\"M\n\x0bNestingMode\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06SINGLE\x10\x01\x12\x08\n\x04LIST\x10\x02\x12\x07\n\x03SET\x10\x03\x12\x07\n\x03MAP\x10\x04\x12\t\n\x05GROUP\x10\x05\"\xc5\x03\n\x11GetProviderSchema\x1a\t\n\x07Request\x1a\xa4\x03\n\x08Response\x12#\n\x08provider\x18\x01 \x01(\x0b\x32\x11.tfplugin5.Schema\x12T\n\x10resource_schemas\x18\x02 \x03(\x0b\x32:.tfplugin5.GetProviderSchema.Response.ResourceSchemasEntry\x12Y\n\x13\x64\x61ta_source_schemas\x18\x03 \x03(\x0b\x32<.tfplugin5.GetProviderSchema.Response.DataSourceSchemasEntry\x12*\n\x0b\x64iagnostics\x18\x04 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\x1aI\n\x14ResourceSchemasEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.tfplugin5.Schema:\x02\x38\x01\x1aK\n\x16\x44\x61taSourceSchemasEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.tfplugin5.Schema:\x02\x38\x01\"\xb5\x01\n\x15PrepareProviderConfig\x1a\x32\n\x07Request\x12\'\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1ah\n\x08Response\x12\x30\n\x0fprepared_config\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\xd6\x01\n\x14UpgradeResourceState\x1aU\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x03\x12&\n\traw_state\x18\x03 \x01(\x0b\x32\x13.tfplugin5.RawState\x1ag\n\x08Response\x12/\n\x0eupgraded_state\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\x9b\x01\n\x1aValidateResourceTypeConfig\x1a\x45\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a\x36\n\x08Response\x12*\n\x0b\x64iagnostics\x18\x01 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\x99\x01\n\x18ValidateDataSourceConfig\x1a\x45\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a\x36\n\x08Response\x12*\n\x0b\x64iagnostics\x18\x01 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\x92\x01\n\tConfigure\x1aM\n\x07Request\x12\x19\n\x11terraform_version\x18\x01 \x01(\t\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a\x36\n\x08Response\x12*\n\x0b\x64iagnostics\x18\x01 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\xe2\x01\n\x0cReadResource\x1a]\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12.\n\rcurrent_state\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x0f\n\x07private\x18\x03 \x01(\x0c\x1as\n\x08Response\x12*\n\tnew_state\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\x12\x0f\n\x07private\x18\x03 \x01(\x0c\"\xa8\x03\n\x12PlanResourceChange\x1a\xbf\x01\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12,\n\x0bprior_state\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x33\n\x12proposed_new_state\x18\x03 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\'\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x15\n\rprior_private\x18\x05 \x01(\x0c\x1a\xcf\x01\n\x08Response\x12.\n\rplanned_state\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x32\n\x10requires_replace\x18\x02 \x03(\x0b\x32\x18.tfplugin5.AttributePath\x12\x17\n\x0fplanned_private\x18\x03 \x01(\x0c\x12*\n\x0b\x64iagnostics\x18\x04 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\x12\x1a\n\x12legacy_type_system\x18\x05 \x01(\x08\"\xe6\x02\n\x13\x41pplyResourceChange\x1a\xbc\x01\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12,\n\x0bprior_state\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12.\n\rplanned_state\x18\x03 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\'\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x17\n\x0fplanned_private\x18\x05 \x01(\x0c\x1a\x8f\x01\n\x08Response\x12*\n\tnew_state\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x0f\n\x07private\x18\x02 \x01(\x0c\x12*\n\x0b\x64iagnostics\x18\x03 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\x12\x1a\n\x12legacy_type_system\x18\x04 \x01(\x08\"\xa5\x02\n\x13ImportResourceState\x1a(\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x1a^\n\x10ImportedResource\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12&\n\x05state\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12\x0f\n\x07private\x18\x03 \x01(\x0c\x1a\x83\x01\n\x08Response\x12K\n\x12imported_resources\x18\x01 \x03(\x0b\x32/.tfplugin5.ImportResourceState.ImportedResource\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\xb7\x01\n\x0eReadDataSource\x1a\x45\n\x07Request\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a^\n\x08Response\x12&\n\x05state\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\x81\x01\n\x14GetProvisionerSchema\x1a\t\n\x07Request\x1a^\n\x08Response\x12&\n\x0bprovisioner\x18\x01 \x01(\x0b\x32\x11.tfplugin5.Schema\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\x87\x01\n\x19ValidateProvisionerConfig\x1a\x32\n\x07Request\x12\'\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a\x36\n\x08Response\x12*\n\x0b\x64iagnostics\x18\x01 \x03(\x0b\x32\x15.tfplugin5.Diagnostic\"\xbc\x01\n\x11ProvisionResource\x1a_\n\x07Request\x12\'\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x12+\n\nconnection\x18\x02 \x01(\x0b\x32\x17.tfplugin5.DynamicValue\x1a\x46\n\x08Response\x12\x0e\n\x06output\x18\x01 \x01(\t\x12*\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x15.tfplugin5.Diagnostic2\x97\t\n\x08Provider\x12X\n\tGetSchema\x12$.tfplugin5.GetProviderSchema.Request\x1a%.tfplugin5.GetProviderSchema.Response\x12l\n\x15PrepareProviderConfig\x12(.tfplugin5.PrepareProviderConfig.Request\x1a).tfplugin5.PrepareProviderConfig.Response\x12{\n\x1aValidateResourceTypeConfig\x12-.tfplugin5.ValidateResourceTypeConfig.Request\x1a..tfplugin5.ValidateResourceTypeConfig.Response\x12u\n\x18ValidateDataSourceConfig\x12+.tfplugin5.ValidateDataSourceConfig.Request\x1a,.tfplugin5.ValidateDataSourceConfig.Response\x12i\n\x14UpgradeResourceState\x12\'.tfplugin5.UpgradeResourceState.Request\x1a(.tfplugin5.UpgradeResourceState.Response\x12H\n\tConfigure\x12\x1c.tfplugin5.Configure.Request\x1a\x1d.tfplugin5.Configure.Response\x12Q\n\x0cReadResource\x12\x1f.tfplugin5.ReadResource.Request\x1a .tfplugin5.ReadResource.Response\x12\x63\n\x12PlanResourceChange\x12%.tfplugin5.PlanResourceChange.Request\x1a&.tfplugin5.PlanResourceChange.Response\x12\x66\n\x13\x41pplyResourceChange\x12&.tfplugin5.ApplyResourceChange.Request\x1a\'.tfplugin5.ApplyResourceChange.Response\x12\x66\n\x13ImportResourceState\x12&.tfplugin5.ImportResourceState.Request\x1a\'.tfplugin5.ImportResourceState.Response\x12W\n\x0eReadDataSource\x12!.tfplugin5.ReadDataSource.Request\x1a\".tfplugin5.ReadDataSource.Response\x12\x39\n\x04Stop\x12\x17.tfplugin5.Stop.Request\x1a\x18.tfplugin5.Stop.Response2\x86\x03\n\x0bProvisioner\x12^\n\tGetSchema\x12\'.tfplugin5.GetProvisionerSchema.Request\x1a(.tfplugin5.GetProvisionerSchema.Response\x12x\n\x19ValidateProvisionerConfig\x12,.tfplugin5.ValidateProvisionerConfig.Request\x1a-.tfplugin5.ValidateProvisionerConfig.Response\x12\x62\n\x11ProvisionResource\x12$.tfplugin5.ProvisionResource.Request\x1a%.tfplugin5.ProvisionResource.Response0\x01\x12\x39\n\x04Stop\x12\x17.tfplugin5.Stop.Request\x1a\x18.tfplugin5.Stop.Responseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tfplugin5_0_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _RAWSTATE_FLATMAPENTRY._options = None
  _RAWSTATE_FLATMAPENTRY._serialized_options = b'8\001'
  _GETPROVIDERSCHEMA_RESPONSE_RESOURCESCHEMASENTRY._options = None
  _GETPROVIDERSCHEMA_RESPONSE_RESOURCESCHEMASENTRY._serialized_options = b'8\001'
  _GETPROVIDERSCHEMA_RESPONSE_DATASOURCESCHEMASENTRY._options = None
  _GETPROVIDERSCHEMA_RESPONSE_DATASOURCESCHEMASENTRY._serialized_options = b'8\001'
  _globals['_DYNAMICVALUE']._serialized_start=32
  _globals['_DYNAMICVALUE']._serialized_end=77
  _globals['_DIAGNOSTIC']._serialized_start=80
  _globals['_DIAGNOSTIC']._serialized_end=269
  _globals['_DIAGNOSTIC_SEVERITY']._serialized_start=222
  _globals['_DIAGNOSTIC_SEVERITY']._serialized_end=269
  _globals['_ATTRIBUTEPATH']._serialized_start=272
  _globals['_ATTRIBUTEPATH']._serialized_end=436
  _globals['_ATTRIBUTEPATH_STEP']._serialized_start=335
  _globals['_ATTRIBUTEPATH_STEP']._serialized_end=436
  _globals['_STOP']._serialized_start=438
  _globals['_STOP']._serialized_end=482
  _globals['_STOP_REQUEST']._serialized_start=446
  _globals['_STOP_REQUEST']._serialized_end=455
  _globals['_STOP_RESPONSE']._serialized_start=457
  _globals['_STOP_RESPONSE']._serialized_end=482
  _globals['_RAWSTATE']._serialized_start=484
  _globals['_RAWSTATE']._serialized_end=607
  _globals['_RAWSTATE_FLATMAPENTRY']._serialized_start=561
  _globals['_RAWSTATE_FLATMAPENTRY']._serialized_end=607
  _globals['_SCHEMA']._serialized_start=610
  _globals['_SCHEMA']._serialized_end=1190
  _globals['_SCHEMA_BLOCK']._serialized_start=677
  _globals['_SCHEMA_BLOCK']._serialized_end=802
  _globals['_SCHEMA_ATTRIBUTE']._serialized_start=805
  _globals['_SCHEMA_ATTRIBUTE']._serialized_end=938
  _globals['_SCHEMA_NESTEDBLOCK']._serialized_start=941
  _globals['_SCHEMA_NESTEDBLOCK']._serialized_end=1190
  _globals['_SCHEMA_NESTEDBLOCK_NESTINGMODE']._serialized_start=1113
  _globals['_SCHEMA_NESTEDBLOCK_NESTINGMODE']._serialized_end=1190
  _globals['_GETPROVIDERSCHEMA']._serialized_start=1193
  _globals['_GETPROVIDERSCHEMA']._serialized_end=1646
  _globals['_GETPROVIDERSCHEMA_REQUEST']._serialized_start=446
  _globals['_GETPROVIDERSCHEMA_REQUEST']._serialized_end=455
  _globals['_GETPROVIDERSCHEMA_RESPONSE']._serialized_start=1226
  _globals['_GETPROVIDERSCHEMA_RESPONSE']._serialized_end=1646
  _globals['_GETPROVIDERSCHEMA_RESPONSE_RESOURCESCHEMASENTRY']._serialized_start=1496
  _globals['_GETPROVIDERSCHEMA_RESPONSE_RESOURCESCHEMASENTRY']._serialized_end=1569
  _globals['_GETPROVIDERSCHEMA_RESPONSE_DATASOURCESCHEMASENTRY']._serialized_start=1571
  _globals['_GETPROVIDERSCHEMA_RESPONSE_DATASOURCESCHEMASENTRY']._serialized_end=1646
  _globals['_PREPAREPROVIDERCONFIG']._serialized_start=1649
  _globals['_PREPAREPROVIDERCONFIG']._serialized_end=1830
  _globals['_PREPAREPROVIDERCONFIG_REQUEST']._serialized_start=1674
  _globals['_PREPAREPROVIDERCONFIG_REQUEST']._serialized_end=1724
  _globals['_PREPAREPROVIDERCONFIG_RESPONSE']._serialized_start=1726
  _globals['_PREPAREPROVIDERCONFIG_RESPONSE']._serialized_end=1830
  _globals['_UPGRADERESOURCESTATE']._serialized_start=1833
  _globals['_UPGRADERESOURCESTATE']._serialized_end=2047
  _globals['_UPGRADERESOURCESTATE_REQUEST']._serialized_start=1857
  _globals['_UPGRADERESOURCESTATE_REQUEST']._serialized_end=1942
  _globals['_UPGRADERESOURCESTATE_RESPONSE']._serialized_start=1944
  _globals['_UPGRADERESOURCESTATE_RESPONSE']._serialized_end=2047
  _globals['_VALIDATERESOURCETYPECONFIG']._serialized_start=2050
  _globals['_VALIDATERESOURCETYPECONFIG']._serialized_end=2205
  _globals['_VALIDATERESOURCETYPECONFIG_REQUEST']._serialized_start=2080
  _globals['_VALIDATERESOURCETYPECONFIG_REQUEST']._serialized_end=2149
  _globals['_VALIDATERESOURCETYPECONFIG_RESPONSE']._serialized_start=2151
  _globals['_VALIDATERESOURCETYPECONFIG_RESPONSE']._serialized_end=2205
  _globals['_VALIDATEDATASOURCECONFIG']._serialized_start=2208
  _globals['_VALIDATEDATASOURCECONFIG']._serialized_end=2361
  _globals['_VALIDATEDATASOURCECONFIG_REQUEST']._serialized_start=2080
  _globals['_VALIDATEDATASOURCECONFIG_REQUEST']._serialized_end=2149
  _globals['_VALIDATEDATASOURCECONFIG_RESPONSE']._serialized_start=2151
  _globals['_VALIDATEDATASOURCECONFIG_RESPONSE']._serialized_end=2205
  _globals['_CONFIGURE']._serialized_start=2364
  _globals['_CONFIGURE']._serialized_end=2510
  _globals['_CONFIGURE_REQUEST']._serialized_start=2377
  _globals['_CONFIGURE_REQUEST']._serialized_end=2454
  _globals['_CONFIGURE_RESPONSE']._serialized_start=2151
  _globals['_CONFIGURE_RESPONSE']._serialized_end=2205
  _globals['_READRESOURCE']._serialized_start=2513
  _globals['_READRESOURCE']._serialized_end=2739
  _globals['_READRESOURCE_REQUEST']._serialized_start=2529
  _globals['_READRESOURCE_REQUEST']._serialized_end=2622
  _globals['_READRESOURCE_RESPONSE']._serialized_start=2624
  _globals['_READRESOURCE_RESPONSE']._serialized_end=2739
  _globals['_PLANRESOURCECHANGE']._serialized_start=2742
  _globals['_PLANRESOURCECHANGE']._serialized_end=3166
  _globals['_PLANRESOURCECHANGE_REQUEST']._serialized_start=2765
  _globals['_PLANRESOURCECHANGE_REQUEST']._serialized_end=2956
  _globals['_PLANRESOURCECHANGE_RESPONSE']._serialized_start=2959
  _globals['_PLANRESOURCECHANGE_RESPONSE']._serialized_end=3166
  _globals['_APPLYRESOURCECHANGE']._serialized_start=3169
  _globals['_APPLYRESOURCECHANGE']._serialized_end=3527
  _globals['_APPLYRESOURCECHANGE_REQUEST']._serialized_start=3193
  _globals['_APPLYRESOURCECHANGE_REQUEST']._serialized_end=3381
  _globals['_APPLYRESOURCECHANGE_RESPONSE']._serialized_start=3384
  _globals['_APPLYRESOURCECHANGE_RESPONSE']._serialized_end=3527
  _globals['_IMPORTRESOURCESTATE']._serialized_start=3530
  _globals['_IMPORTRESOURCESTATE']._serialized_end=3823
  _globals['_IMPORTRESOURCESTATE_REQUEST']._serialized_start=3553
  _globals['_IMPORTRESOURCESTATE_REQUEST']._serialized_end=3593
  _globals['_IMPORTRESOURCESTATE_IMPORTEDRESOURCE']._serialized_start=3595
  _globals['_IMPORTRESOURCESTATE_IMPORTEDRESOURCE']._serialized_end=3689
  _globals['_IMPORTRESOURCESTATE_RESPONSE']._serialized_start=3692
  _globals['_IMPORTRESOURCESTATE_RESPONSE']._serialized_end=3823
  _globals['_READDATASOURCE']._serialized_start=3826
  _globals['_READDATASOURCE']._serialized_end=4009
  _globals['_READDATASOURCE_REQUEST']._serialized_start=2080
  _globals['_READDATASOURCE_REQUEST']._serialized_end=2149
  _globals['_READDATASOURCE_RESPONSE']._serialized_start=3915
  _globals['_READDATASOURCE_RESPONSE']._serialized_end=4009
  _globals['_GETPROVISIONERSCHEMA']._serialized_start=4012
  _globals['_GETPROVISIONERSCHEMA']._serialized_end=4141
  _globals['_GETPROVISIONERSCHEMA_REQUEST']._serialized_start=446
  _globals['_GETPROVISIONERSCHEMA_REQUEST']._serialized_end=455
  _globals['_GETPROVISIONERSCHEMA_RESPONSE']._serialized_start=4047
  _globals['_GETPROVISIONERSCHEMA_RESPONSE']._serialized_end=4141
  _globals['_VALIDATEPROVISIONERCONFIG']._serialized_start=4144
  _globals['_VALIDATEPROVISIONERCONFIG']._serialized_end=4279
  _globals['_VALIDATEPROVISIONERCONFIG_REQUEST']._serialized_start=1674
  _globals['_VALIDATEPROVISIONERCONFIG_REQUEST']._serialized_end=1724
  _globals['_VALIDATEPROVISIONERCONFIG_RESPONSE']._serialized_start=2151
  _globals['_VALIDATEPROVISIONERCONFIG_RESPONSE']._serialized_end=2205
  _globals['_PROVISIONRESOURCE']._serialized_start=4282
  _globals['_PROVISIONRESOURCE']._serialized_end=4470
  _globals['_PROVISIONRESOURCE_REQUEST']._serialized_start=4303
  _globals['_PROVISIONRESOURCE_REQUEST']._serialized_end=4398
  _globals['_PROVISIONRESOURCE_RESPONSE']._serialized_start=4400
  _globals['_PROVISIONRESOURCE_RESPONSE']._serialized_end=4470
  _globals['_PROVIDER']._serialized_start=4473
  _globals['_PROVIDER']._serialized_end=5648
  _globals['_PROVISIONER']._serialized_start=5651
  _globals['_PROVISIONER']._serialized_end=6041
# @@protoc_insertion_point(module_scope)



from typing import Any
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import tfplugin6_0_pb2 as tfplugin6__0__pb2


class ProviderStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetProviderSchema = channel.unary_unary(
                '/tfplugin6.Provider/GetProviderSchema',
                request_serializer=tfplugin6__0__pb2.GetProviderSchema.Request.SerializeToString,
                response_deserializer=tfplugin6__0__pb2.GetProviderSchema.Response.FromString,
                )
        self.ValidateProviderConfig = channel.unary_unary(
                '/tfplugin6.Provider/ValidateProviderConfig',
                request_serializer=tfplugin6__0__pb2.ValidateProviderConfig.Request.SerializeToString,
                response_deserializer=tfplugin6__0__pb2.ValidateProviderConfig.Response.FromString,
                )
        self.ValidateResourceConfig = channel.unary_unary(
                '/tfplugin6.Provider/ValidateResourceConfig',
                request_serializer=tfplugin6__0__pb2.ValidateResourceConfig.Request.SerializeToString,
                response_deserializer=tfplugin6__0__pb2.ValidateResourceConfig.Response.FromString,
                )
        self.ValidateDataResourceConfig = channel.unary_unary(
                '/tfplugin6.Provider/ValidateDataResourceConfig',
                request_serializer=tfplugin6__0__pb2.ValidateDataResourceConfig.Request.SerializeToString,
                response_deserializer=tfplugin6__0__pb2.ValidateDataResourceConfig.Response.FromString,
                )
        self.UpgradeResourceState = channel.unary_unary(
                '/tfplugin6.Provider/UpgradeResourceState',
                request_serializer=tfplugin6__0__pb2.UpgradeResourceState.Request.SerializeToString,
                response_deserializer=tfplugin6__0__pb2.UpgradeResourceState.Response.FromString,
                )
        self.ConfigureProvider = channel.unary_unary(
                '/tfplugin6.Provider/ConfigureProvider',
                request_serializer=tfplugin6__0__pb2.ConfigureProvider.Request.SerializeToString,
                response_deserializer=tfplugin6__0__pb2.ConfigureProvider.Response.FromString,
                )
        self.ReadResource = channel.unary_unary(
                '/tfplugin6.Provider/ReadResource',
                request_serializer=tfplugin6__0__pb2.ReadResource.Request.SerializeToString,
                response_deserializer=tfplugin6__0__pb2.ReadResource.Response.FromString,
                )
        self.PlanResourceChange = channel.unary_unary(
                '/tfplugin6.Provider/PlanResourceChange',
                request_serializer=tfplugin6__0__pb2.PlanResourceChange.Request.SerializeToString,
                response_deserializer=tfplugin6__0__pb2.PlanResourceChange.Response.FromString,
                )
        self.ApplyResourceChange = channel.unary_unary(
                '/tfplugin6.Provider/ApplyResourceChange',
                request_serializer=tfplugin6__0__pb2.ApplyResourceChange.Request.SerializeToString,
                response_deserializer=tfplugin6__0__pb2.ApplyResourceChange.Response.FromString,
                )
        self.ImportResourceState = channel.unary_unary(
                '/tfplugin6.Provider/ImportResourceState',
                request_serializer=tfplugin6__0__pb2.ImportResourceState.Request.SerializeToString,
                response_deserializer=tfplugin6__0__pb2.ImportResourceState.Response.FromString,
                )
        self.ReadDataSource = channel.unary_unary(
                '/tfplugin6.Provider/ReadDataSource',
                request_serializer=tfplugin6__0__pb2.ReadDataSource.Request.SerializeToString,
                response_deserializer=tfplugin6__0__pb2.ReadDataSource.Response.FromString,
                )
        self.StopProvider = channel.unary_unary(
                '/tfplugin6.Provider/StopProvider',
                request_serializer=tfplugin6__0__pb2.StopProvider.Request.SerializeToString,
                response_deserializer=tfplugin6__0__pb2.StopProvider.Response.FromString,
                )


class ProviderServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetProviderSchema(self, request, context):
        """////// Information about what a provider supports/expects
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateProviderConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateResourceConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateDataResourceConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpgradeResourceState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureProvider(self, request, context):
        """////// One-time initialization, called before other functions below
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadResource(self, request, context):
        """////// Managed Resource Lifecycle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlanResourceChange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyResourceChange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ImportResourceState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadDataSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopProvider(self, request, context):
        """////// Graceful Shutdown
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProviderServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetProviderSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProviderSchema,
                    request_deserializer=tfplugin6__0__pb2.GetProviderSchema.Request.FromString,
                    response_serializer=tfplugin6__0__pb2.GetProviderSchema.Response.SerializeToString,
            ),
            'ValidateProviderConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateProviderConfig,
                    request_deserializer=tfplugin6__0__pb2.ValidateProviderConfig.Request.FromString,
                    response_serializer=tfplugin6__0__pb2.ValidateProviderConfig.Response.SerializeToString,
            ),
            'ValidateResourceConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateResourceConfig,
                    request_deserializer=tfplugin6__0__pb2.ValidateResourceConfig.Request.FromString,
                    response_serializer=tfplugin6__0__pb2.ValidateResourceConfig.Response.SerializeToString,
            ),
            'ValidateDataResourceConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateDataResourceConfig,
                    request_deserializer=tfplugin6__0__pb2.ValidateDataResourceConfig.Request.FromString,
                    response_serializer=tfplugin6__0__pb2.ValidateDataResourceConfig.Response.SerializeToString,
            ),
            'UpgradeResourceState': grpc.unary_unary_rpc_method_handler(
                    servicer.UpgradeResourceState,
                    request_deserializer=tfplugin6__0__pb2.UpgradeResourceState.Request.FromString,
                    response_serializer=tfplugin6__0__pb2.UpgradeResourceState.Response.SerializeToString,
            ),
            'ConfigureProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureProvider,
                    request_deserializer=tfplugin6__0__pb2.ConfigureProvider.Request.FromString,
                    response_serializer=tfplugin6__0__pb2.ConfigureProvider.Response.SerializeToString,
            ),
            'ReadResource': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadResource,
                    request_deserializer=tfplugin6__0__pb2.ReadResource.Request.FromString,
                    response_serializer=tfplugin6__0__pb2.ReadResource.Response.SerializeToString,
            ),
            'PlanResourceChange': grpc.unary_unary_rpc_method_handler(
                    servicer.PlanResourceChange,
                    request_deserializer=tfplugin6__0__pb2.PlanResourceChange.Request.FromString,
                    response_serializer=tfplugin6__0__pb2.PlanResourceChange.Response.SerializeToString,
            ),
            'ApplyResourceChange': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyResourceChange,
                    request_deserializer=tfplugin6__0__pb2.ApplyResourceChange.Request.FromString,
                    response_serializer=tfplugin6__0__pb2.ApplyResourceChange.Response.SerializeToString,
            ),
            'ImportResourceState': grpc.unary_unary_rpc_method_handler(
                    servicer.ImportResourceState,
                    request_deserializer=tfplugin6__0__pb2.ImportResourceState.Request.FromString,
                    response_serializer=tfplugin6__0__pb2.ImportResourceState.Response.SerializeToString,
            ),
            'ReadDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadDataSource,
                    request_deserializer=tfplugin6__0__pb2.ReadDataSource.Request.FromString,
                    response_serializer=tfplugin6__0__pb2.ReadDataSource.Response.SerializeToString,
            ),
            'StopProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.StopProvider,
                    request_deserializer=tfplugin6__0__pb2.StopProvider.Request.FromString,
                    response_serializer=tfplugin6__0__pb2.StopProvider.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tfplugin6.Provider', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Provider(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetProviderSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/GetProviderSchema',
            tfplugin6__0__pb2.GetProviderSchema.Request.SerializeToString,
            tfplugin6__0__pb2.GetProviderSchema.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateProviderConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ValidateProviderConfig',
            tfplugin6__0__pb2.ValidateProviderConfig.Request.SerializeToString,
            tfplugin6__0__pb2.ValidateProviderConfig.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateResourceConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ValidateResourceConfig',
            tfplugin6__0__pb2.ValidateResourceConfig.Request.SerializeToString,
            tfplugin6__0__pb2.ValidateResourceConfig.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateDataResourceConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ValidateDataResourceConfig',
            tfplugin6__0__pb2.ValidateDataResourceConfig.Request.SerializeToString,
            tfplugin6__0__pb2.ValidateDataResourceConfig.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpgradeResourceState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/UpgradeResourceState',
            tfplugin6__0__pb2.UpgradeResourceState.Request.SerializeToString,
            tfplugin6__0__pb2.UpgradeResourceState.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ConfigureProvider',
            tfplugin6__0__pb2.ConfigureProvider.Request.SerializeToString,
            tfplugin6__0__pb2.ConfigureProvider.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ReadResource',
            tfplugin6__0__pb2.ReadResource.Request.SerializeToString,
            tfplugin6__0__pb2.ReadResource.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlanResourceChange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/PlanResourceChange',
            tfplugin6__0__pb2.PlanResourceChange.Request.SerializeToString,
            tfplugin6__0__pb2.PlanResourceChange.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyResourceChange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ApplyResourceChange',
            tfplugin6__0__pb2.ApplyResourceChange.Request.SerializeToString,
            tfplugin6__0__pb2.ApplyResourceChange.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ImportResourceState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ImportResourceState',
            tfplugin6__0__pb2.ImportResourceState.Request.SerializeToString,
            tfplugin6__0__pb2.ImportResourceState.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/ReadDataSource',
            tfplugin6__0__pb2.ReadDataSource.Request.SerializeToString,
            tfplugin6__0__pb2.ReadDataSource.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tfplugin6.Provider/StopProvider',
            tfplugin6__0__pb2.StopProvider.Request.SerializeToString,
            tfplugin6__0__pb2.StopProvider.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import Any
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StringKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__: list[str] = []
    PLAIN: _ClassVar[StringKind]
    MARKDOWN: _ClassVar[StringKind]
PLAIN: StringKind
MARKDOWN: StringKind

class DynamicValue(_message.Message):
    __slots__ = ["msgpack", "json"]
    MSGPACK_FIELD_NUMBER: _ClassVar[int]
    JSON_FIELD_NUMBER: _ClassVar[int]
    msgpack: bytes
    json: bytes
    def __init__(self, msgpack: _Optional[bytes] = ..., json: _Optional[bytes] = ...) -> None: ...

class Diagnostic(_message.Message):
    __slots__ = ["severity", "summary", "detail", "attribute"]
    class Severity(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__: list[str] = []
        INVALID: _ClassVar[Diagnostic.Severity]
        ERROR: _ClassVar[Diagnostic.Severity]
        WARNING: _ClassVar[Diagnostic.Severity]
    INVALID: Diagnostic.Severity
    ERROR: Diagnostic.Severity
    WARNING: Diagnostic.Severity
    SEVERITY_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    DETAIL_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    severity: Diagnostic.Severity
    summary: str
    detail: str
    attribute: AttributePath
    def __init__(self, severity: _Optional[_Union[Diagnostic.Severity, str]] = ..., summary: _Optional[str] = ..., detail: _Optional[str] = ..., attribute: _Optional[_Union[AttributePath, _Mapping[Any, Any]]] = ...) -> None: ...

class AttributePath(_message.Message):
    __slots__ = ["steps"]
    class Step(_message.Message):
        __slots__ = ["attribute_name", "element_key_string", "element_key_int"]
        ATTRIBUTE_NAME_FIELD_NUMBER: _ClassVar[int]
        ELEMENT_KEY_STRING_FIELD_NUMBER: _ClassVar[int]
        ELEMENT_KEY_INT_FIELD_NUMBER: _ClassVar[int]
        attribute_name: str
        element_key_string: str
        element_key_int: int
        def __init__(self, attribute_name: _Optional[str] = ..., element_key_string: _Optional[str] = ..., element_key_int: _Optional[int] = ...) -> None: ...
    STEPS_FIELD_NUMBER: _ClassVar[int]
    steps: _containers.RepeatedCompositeFieldContainer[AttributePath.Step]
    def __init__(self, steps: _Optional[_Iterable[_Union[AttributePath.Step, _Mapping[Any, Any]]]] = ...) -> None: ...

class Stop(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__: list[str] = []
        def __init__(self) -> None: ...
    class Response(_message.Message):
        __slots__ = ["Error"]
        ERROR_FIELD_NUMBER: _ClassVar[int]
        Error: str
        def __init__(self, Error: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class RawState(_message.Message):
    __slots__ = ["json", "flatmap"]
    class FlatmapEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    JSON_FIELD_NUMBER: _ClassVar[int]
    FLATMAP_FIELD_NUMBER: _ClassVar[int]
    json: bytes
    flatmap: _containers.ScalarMap[str, str]
    def __init__(self, json: _Optional[bytes] = ..., flatmap: _Optional[_Mapping[str, str]] = ...) -> None: ...

class Schema(_message.Message):
    __slots__ = ["version", "block"]
    class Block(_message.Message):
        __slots__ = ["version", "attributes", "block_types", "description", "description_kind", "deprecated"]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
        BLOCK_TYPES_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_KIND_FIELD_NUMBER: _ClassVar[int]
        DEPRECATED_FIELD_NUMBER: _ClassVar[int]
        version: int
        attributes: _containers.RepeatedCompositeFieldContainer[Schema.Attribute]
        block_types: _containers.RepeatedCompositeFieldContainer[Schema.NestedBlock]
        description: str
        description_kind: StringKind
        deprecated: bool
        def __init__(self, version: _Optional[int] = ..., attributes: _Optional[_Iterable[_Union[Schema.Attribute, _Mapping[Any, Any]]]] = ..., block_types: _Optional[_Iterable[_Union[Schema.NestedBlock, _Mapping[Any, Any]]]] = ..., description: _Optional[str] = ..., description_kind: _Optional[_Union[StringKind, str]] = ..., deprecated: bool = ...) -> None: ...
    class Attribute(_message.Message):
        __slots__ = ["name", "type", "description", "required", "optional", "computed", "sensitive", "description_kind", "deprecated"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        REQUIRED_FIELD_NUMBER: _ClassVar[int]
        OPTIONAL_FIELD_NUMBER: _ClassVar[int]
        COMPUTED_FIELD_NUMBER: _ClassVar[int]
        SENSITIVE_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_KIND_FIELD_NUMBER: _ClassVar[int]
        DEPRECATED_FIELD_NUMBER: _ClassVar[int]
        name: str
        type: bytes
        description: str
        required: bool
        optional: bool
        computed: bool
        sensitive: bool
        description_kind: StringKind
        deprecated: bool
        def __init__(self, name: _Optional[str] = ..., type: _Optional[bytes] = ..., description: _Optional[str] = ..., required: bool = ..., optional: bool = ..., computed: bool = ..., sensitive: bool = ..., description_kind: _Optional[_Union[StringKind, str]] = ..., deprecated: bool = ...) -> None: ...
    class NestedBlock(_message.Message):
        __slots__ = ["type_name", "block", "nesting", "min_items", "max_items"]
        class NestingMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__: list[str] = []
            INVALID: _ClassVar[Schema.NestedBlock.NestingMode]
            SINGLE: _ClassVar[Schema.NestedBlock.NestingMode]
            LIST: _ClassVar[Schema.NestedBlock.NestingMode]
            SET: _ClassVar[Schema.NestedBlock.NestingMode]
            MAP: _ClassVar[Schema.NestedBlock.NestingMode]
            GROUP: _ClassVar[Schema.NestedBlock.NestingMode]
        INVALID: Schema.NestedBlock.NestingMode
        SINGLE: Schema.NestedBlock.NestingMode
        LIST: Schema.NestedBlock.NestingMode
        SET: Schema.NestedBlock.NestingMode
        MAP: Schema.NestedBlock.NestingMode
        GROUP: Schema.NestedBlock.NestingMode
        TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
        BLOCK_FIELD_NUMBER: _ClassVar[int]
        NESTING_FIELD_NUMBER: _ClassVar[int]
        MIN_ITEMS_FIELD_NUMBER: _ClassVar[int]
        MAX_ITEMS_FIELD_NUMBER: _ClassVar[int]
        type_name: str
        block: Schema.Block
        nesting: Schema.NestedBlock.NestingMode
        min_items: int
        max_items: int
        def __init__(self, type_name: _Optional[str] = ..., block: _Optional[_Union[Schema.Block, _Mapping[Any, Any]]] = ..., nesting: _Optional[_Union[Schema.NestedBlock.NestingMode, str]] = ..., min_items: _Optional[int] = ..., max_items: _Optional[int] = ...) -> None: ...
    VERSION_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    version: int
    block: Schema.Block
    def __init__(self, version: _Optional[int] = ..., block: _Optional[_Union[Schema.Block, _Mapping[Any, Any]]] = ...) -> None: ...

class GetProviderSchema(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__: list[str] = []
        def __init__(self) -> None: ...
    class Response(_message.Message):
        __slots__ = ["provider", "resource_schemas", "data_source_schemas", "diagnostics", "provider_meta", "server_capabilities"]
        class ResourceSchemasEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: Schema
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Schema, _Mapping[Any, Any]]] = ...) -> None: ...
        class DataSourceSchemasEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: Schema
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Schema, _Mapping[Any, Any]]] = ...) -> None: ...
        PROVIDER_FIELD_NUMBER: _ClassVar[int]
        RESOURCE_SCHEMAS_FIELD_NUMBER: _ClassVar[int]
        DATA_SOURCE_SCHEMAS_FIELD_NUMBER: _ClassVar[int]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        PROVIDER_META_FIELD_NUMBER: _ClassVar[int]
        SERVER_CAPABILITIES_FIELD_NUMBER: _ClassVar[int]
        provider: Schema
        resource_schemas: _containers.MessageMap[str, Schema]
        data_source_schemas: _containers.MessageMap[str, Schema]
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        provider_meta: Schema
        server_capabilities: GetProviderSchema.ServerCapabilities
        def __init__(self, provider: _Optional[_Union[Schema, _Mapping[Any, Any]]] = ..., resource_schemas: _Optional[_Mapping[str, Schema]] = ..., data_source_schemas: _Optional[_Mapping[str, Schema]] = ..., diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ..., provider_meta: _Optional[_Union[Schema, _Mapping[Any, Any]]] = ..., server_capabilities: _Optional[_Union[GetProviderSchema.ServerCapabilities, _Mapping[Any, Any]]] = ...) -> None: ...
    class ServerCapabilities(_message.Message):
        __slots__ = ["plan_destroy"]
        PLAN_DESTROY_FIELD_NUMBER: _ClassVar[int]
        plan_destroy: bool
        def __init__(self, plan_destroy: bool = ...) -> None: ...
    def __init__(self) -> None: ...

class PrepareProviderConfig(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__ = ["config"]
        CONFIG_FIELD_NUMBER: _ClassVar[int]
        config: DynamicValue
        def __init__(self, config: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ["prepared_config", "diagnostics"]
        PREPARED_CONFIG_FIELD_NUMBER: _ClassVar[int]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        prepared_config: DynamicValue
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        def __init__(self, prepared_config: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ...) -> None: ...
    def __init__(self) -> None: ...

class UpgradeResourceState(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__ = ["type_name", "version", "raw_state"]
        TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        RAW_STATE_FIELD_NUMBER: _ClassVar[int]
        type_name: str
        version: int
        raw_state: RawState
        def __init__(self, type_name: _Optional[str] = ..., version: _Optional[int] = ..., raw_state: _Optional[_Union[RawState, _Mapping[Any, Any]]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ["upgraded_state", "diagnostics"]
        UPGRADED_STATE_FIELD_NUMBER: _ClassVar[int]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        upgraded_state: DynamicValue
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        def __init__(self, upgraded_state: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ...) -> None: ...
    def __init__(self) -> None: ...

class ValidateResourceTypeConfig(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__ = ["type_name", "config"]
        TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
        CONFIG_FIELD_NUMBER: _ClassVar[int]
        type_name: str
        config: DynamicValue
        def __init__(self, type_name: _Optional[str] = ..., config: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ["diagnostics"]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        def __init__(self, diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ...) -> None: ...
    def __init__(self) -> None: ...

class ValidateDataSourceConfig(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__ = ["type_name", "config"]
        TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
        CONFIG_FIELD_NUMBER: _ClassVar[int]
        type_name: str
        config: DynamicValue
        def __init__(self, type_name: _Optional[str] = ..., config: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ["diagnostics"]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        def __init__(self, diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ...) -> None: ...
    def __init__(self) -> None: ...

class Configure(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__ = ["terraform_version", "config"]
        TERRAFORM_VERSION_FIELD_NUMBER: _ClassVar[int]
        CONFIG_FIELD_NUMBER: _ClassVar[int]
        terraform_version: str
        config: DynamicValue
        def __init__(self, terraform_version: _Optional[str] = ..., config: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ["diagnostics"]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        def __init__(self, diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ...) -> None: ...
    def __init__(self) -> None: ...

class ReadResource(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__ = ["type_name", "current_state", "private", "provider_meta"]
        TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
        CURRENT_STATE_FIELD_NUMBER: _ClassVar[int]
        PRIVATE_FIELD_NUMBER: _ClassVar[int]
        PROVIDER_META_FIELD_NUMBER: _ClassVar[int]
        type_name: str
        current_state: DynamicValue
        private: bytes
        provider_meta: DynamicValue
        def __init__(self, type_name: _Optional[str] = ..., current_state: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., private: _Optional[bytes] = ..., provider_meta: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ["new_state", "diagnostics", "private"]
        NEW_STATE_FIELD_NUMBER: _ClassVar[int]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        PRIVATE_FIELD_NUMBER: _ClassVar[int]
        new_state: DynamicValue
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        private: bytes
        def __init__(self, new_state: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ..., private: _Optional[bytes] = ...) -> None: ...
    def __init__(self) -> None: ...

class PlanResourceChange(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__ = ["type_name", "prior_state", "proposed_new_state", "config", "prior_private", "provider_meta"]
        TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
        PRIOR_STATE_FIELD_NUMBER: _ClassVar[int]
        PROPOSED_NEW_STATE_FIELD_NUMBER: _ClassVar[int]
        CONFIG_FIELD_NUMBER: _ClassVar[int]
        PRIOR_PRIVATE_FIELD_NUMBER: _ClassVar[int]
        PROVIDER_META_FIELD_NUMBER: _ClassVar[int]
        type_name: str
        prior_state: DynamicValue
        proposed_new_state: DynamicValue
        config: DynamicValue
        prior_private: bytes
        provider_meta: DynamicValue
        def __init__(self, type_name: _Optional[str] = ..., prior_state: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., proposed_new_state: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., config: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., prior_private: _Optional[bytes] = ..., provider_meta: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ["planned_state", "requires_replace", "planned_private", "diagnostics", "legacy_type_system"]
        PLANNED_STATE_FIELD_NUMBER: _ClassVar[int]
        REQUIRES_REPLACE_FIELD_NUMBER: _ClassVar[int]
        PLANNED_PRIVATE_FIELD_NUMBER: _ClassVar[int]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        LEGACY_TYPE_SYSTEM_FIELD_NUMBER: _ClassVar[int]
        planned_state: DynamicValue
        requires_replace: _containers.RepeatedCompositeFieldContainer[AttributePath]
        planned_private: bytes
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        legacy_type_system: bool
        def __init__(self, planned_state: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., requires_replace: _Optional[_Iterable[_Union[AttributePath, _Mapping[Any, Any]]]] = ..., planned_private: _Optional[bytes] = ..., diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ..., legacy_type_system: bool = ...) -> None: ...
    def __init__(self) -> None: ...

class ApplyResourceChange(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__ = ["type_name", "prior_state", "planned_state", "config", "planned_private", "provider_meta"]
        TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
        PRIOR_STATE_FIELD_NUMBER: _ClassVar[int]
        PLANNED_STATE_FIELD_NUMBER: _ClassVar[int]
        CONFIG_FIELD_NUMBER: _ClassVar[int]
        PLANNED_PRIVATE_FIELD_NUMBER: _ClassVar[int]
        PROVIDER_META_FIELD_NUMBER: _ClassVar[int]
        type_name: str
        prior_state: DynamicValue
        planned_state: DynamicValue
        config: DynamicValue
        planned_private: bytes
        provider_meta: DynamicValue
        def __init__(self, type_name: _Optional[str] = ..., prior_state: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., planned_state: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., config: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., planned_private: _Optional[bytes] = ..., provider_meta: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ["new_state", "private", "diagnostics", "legacy_type_system"]
        NEW_STATE_FIELD_NUMBER: _ClassVar[int]
        PRIVATE_FIELD_NUMBER: _ClassVar[int]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        LEGACY_TYPE_SYSTEM_FIELD_NUMBER: _ClassVar[int]
        new_state: DynamicValue
        private: bytes
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        legacy_type_system: bool
        def __init__(self, new_state: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., private: _Optional[bytes] = ..., diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ..., legacy_type_system: bool = ...) -> None: ...
    def __init__(self) -> None: ...

class ImportResourceState(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__ = ["type_name", "id"]
        TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        type_name: str
        id: str
        def __init__(self, type_name: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...
    class ImportedResource(_message.Message):
        __slots__ = ["type_name", "state", "private"]
        TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
        STATE_FIELD_NUMBER: _ClassVar[int]
        PRIVATE_FIELD_NUMBER: _ClassVar[int]
        type_name: str
        state: DynamicValue
        private: bytes
        def __init__(self, type_name: _Optional[str] = ..., state: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., private: _Optional[bytes] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ["imported_resources", "diagnostics"]
        IMPORTED_RESOURCES_FIELD_NUMBER: _ClassVar[int]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        imported_resources: _containers.RepeatedCompositeFieldContainer[ImportResourceState.ImportedResource]
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        def __init__(self, imported_resources: _Optional[_Iterable[_Union[ImportResourceState.ImportedResource, _Mapping[Any, Any]]]] = ..., diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ...) -> None: ...
    def __init__(self) -> None: ...

class ReadDataSource(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__ = ["type_name", "config", "provider_meta"]
        TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
        CONFIG_FIELD_NUMBER: _ClassVar[int]
        PROVIDER_META_FIELD_NUMBER: _ClassVar[int]
        type_name: str
        config: DynamicValue
        provider_meta: DynamicValue
        def __init__(self, type_name: _Optional[str] = ..., config: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., provider_meta: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ["state", "diagnostics"]
        STATE_FIELD_NUMBER: _ClassVar[int]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        state: DynamicValue
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        def __init__(self, state: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ...) -> None: ...
    def __init__(self) -> None: ...

class GetProvisionerSchema(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__: list[str] = []
        def __init__(self) -> None: ...
    class Response(_message.Message):
        __slots__ = ["provisioner", "diagnostics"]
        PROVISIONER_FIELD_NUMBER: _ClassVar[int]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        provisioner: Schema
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        def __init__(self, provisioner: _Optional[_Union[Schema, _Mapping[Any, Any]]] = ..., diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ...) -> None: ...
    def __init__(self) -> None: ...

class ValidateProvisionerConfig(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__ = ["config"]
        CONFIG_FIELD_NUMBER: _ClassVar[int]
        config: DynamicValue
        def __init__(self, config: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ["diagnostics"]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        def __init__(self, diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ...) -> None: ...
    def __init__(self) -> None: ...

class ProvisionResource(_message.Message):
    __slots__: list[str] = []
    class Request(_message.Message):
        __slots__ = ["config", "connection"]
        CONFIG_FIELD_NUMBER: _ClassVar[int]
        CONNECTION_FIELD_NUMBER: _ClassVar[int]
        config: DynamicValue
        connection: DynamicValue
        def __init__(self, config: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ..., connection: _Optional[_Union[DynamicValue, _Mapping[Any, Any]]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ["output", "diagnostics"]
        OUTPUT_FIELD_NUMBER: _ClassVar[int]
        DIAGNOSTICS_FIELD_NUMBER: _ClassVar[int]
        output: str
        diagnostics: _containers.RepeatedCompositeFieldContainer[Diagnostic]
        def __init__(self, output: _Optional[str] = ..., diagnostics: _Optional[_Iterable[_Union[Diagnostic, _Mapping[Any, Any]]]] = ...) -> None: ...
    def __init__(self) -> None: ...
